@@ -104,6 +104,9 @@ FAILEDOPERATION_DOMAINNOTBINDSERVICE = 'FailedOperation.DomainNotBindService'
 # The domain name is not configured with a CNAME record resolving to the default domain name, or the resolution has not taken effect yet.
 FAILEDOPERATION_DOMAINRESOLVEERROR = 'FailedOperation.DomainResolveError'
 
+# Error form EIAM
+FAILEDOPERATION_EIAMERROR = 'FailedOperation.EIAMError'
+
 # Failed to bind/unbind EventBridge.
 FAILEDOPERATION_EBERROR = 'FailedOperation.EbError'
 
@@ -125,6 +128,9 @@ FAILEDOPERATION_ISDEFAULTMAPPING = 'FailedOperation.IsDefaultMapping'
 # The entered default second-level domain name is incorrect.
 FAILEDOPERATION_NETSUBDOMAINERROR = 'FailedOperation.NetSubDomainError'
 
+# Backend error
+FAILEDOPERATION_OPERATEUPSTREAM = 'FailedOperation.OperateUpstream'
+
 # An error occurred while setting the path mapping.
 FAILEDOPERATION_PATHMAPPINGSETERROR = 'FailedOperation.PathMappingSetError'
 
@@ -161,7 +167,7 @@ INTERNALERROR_APIGWEXCEPTION = 'InternalError.ApigwException'
 # CAuth internal request error. Please try again later. If the problem persists, please submit a ticket.
 INTERNALERROR_CAUTHEXCEPTION = 'InternalError.CauthException'
 
-# 
+# CLB internal request error. Please try again. If the problem persists, please submit a ticket.
 INTERNALERROR_CLBEXCEPTION = 'InternalError.ClbException'
 
 # OSS internal request error. Please try again. If the problem persists, please contact the smart customer service or submit a ticket.
@@ -179,6 +185,12 @@ INTERNALERROR_VPCEXCEPTION = 'InternalError.VpcException'
 # Incorrect parameter.
 INVALIDPARAMETER = 'InvalidParameter'
 
+# You are using the basic edition and can not be bind a plug-in.
+INVALIDPARAMETER_BASICSERVICENOTALLOWATTACHPLUGIN = 'InvalidParameter.BasicServiceNotAllowAttachPlugin'
+
+# The plugin you want to bound conflicts with existing plugins.
+INVALIDPARAMETER_DUPLICATEPLUGINCONFIG = 'InvalidParameter.DuplicatePluginConfig'
+
 # Incorrect parameter format.
 INVALIDPARAMETER_FORMATERROR = 'InvalidParameter.FormatError'
 
@@ -284,6 +296,9 @@ INVALIDPARAMETERVALUE_INVALIDUPSTREAM = 'InvalidParameterValue.InvalidUpstream'
 # The URL parameters are invalid.
 INVALIDPARAMETERVALUE_INVALIDURL = 'InvalidParameterValue.InvalidUrl'
 
+# Invalid VPC information
+INVALIDPARAMETERVALUE_INVALIDVPCCONFIG = 'InvalidParameterValue.InvalidVpcConfig'
+
 # The method is incorrect. For backend services in the WEBSOCKET type, the frontend method should be configured as GET.
 INVALIDPARAMETERVALUE_INVALIDWSMETHOD = 'InvalidParameterValue.InvalidWSMethod'
 
@@ -314,6 +329,9 @@ LIMITEXCEEDED = 'LimitExceeded'
 # The number of API documents exceeds the limit.
 LIMITEXCEEDED_APIDOCLIMITEXCEEDED = 'LimitExceeded.APIDocLimitExceeded'
 
+# Reached the upper limit of access keys.
+LIMITEXCEEDED_ACCESSKEYCOUNTINUSAGEPLANLIMITEXCEEDED = 'LimitExceeded.AccessKeyCountInUsagePlanLimitExceeded'
+
 # Number of applications bound with the service reaches the upper limit.
 LIMITEXCEEDED_APIAPPCOUNTLIMITEXCEEDED = 'LimitExceeded.ApiAppCountLimitExceeded'
 
@@ -422,6 +440,9 @@ UNSUPPORTEDOPERATION_ALREADYBINDUSAGEPLAN = 'UnsupportedOperation.AlreadyBindUsa
 # The current plugin cannot be bound.
 UNSUPPORTEDOPERATION_ATTACHPLUGIN = 'UnsupportedOperation.AttachPlugin'
 
+# You are using the basic edition and only one API can be created.
+UNSUPPORTEDOPERATION_BASICSERVICENOMOREAPI = 'UnsupportedOperation.BasicServiceNoMoreApi'
+
 # Invalid log query period
 UNSUPPORTEDOPERATION_CLSSEARCHTIME = 'UnsupportedOperation.ClsSearchTime'
 
@@ -479,6 +500,9 @@ UNSUPPORTEDOPERATION_UNSUPPORTEDDELETEAPI = 'UnsupportedOperation.UnsupportedDel
 # This service is being used and cannot be deleted.
 UNSUPPORTEDOPERATION_UNSUPPORTEDDELETESERVICE = 'UnsupportedOperation.UnsupportedDeleteService'
 
+# Operation failed: There are resources associated with this upstream.
+UNSUPPORTEDOPERATION_UNSUPPORTEDDELETEUPSTREAM = 'UnsupportedOperation.UnsupportedDeleteUpstream'
+
 # Unsupported network type
 UNSUPPORTEDOPERATION_UNSUPPORTEDNETTYPE = 'UnsupportedOperation.UnsupportedNetType'
 
