@@ -143,7 +143,7 @@ class MpsClient(AbstractClient):
 
 
     def CreateContentReviewTemplate(self, request):
-        """This API is used to create a custom template for intelligent content recognition. Up to 50 templates can be created.
+        """This API is used to create a custom content moderation template. Up to 50 templates can be created in total.
 
         :param request: Request instance for CreateContentReviewTemplate.
         :type request: :class:`tencentcloud.mps.v20190612.models.CreateContentReviewTemplateRequest`
@@ -533,7 +533,7 @@ class MpsClient(AbstractClient):
 
 
     def DeleteContentReviewTemplate(self, request):
-        """This API is used to delete a custom intelligent content recognition template.
+        """This API is used to delete a custom content moderation template.
 
         :param request: Request instance for DeleteContentReviewTemplate.
         :type request: :class:`tencentcloud.mps.v20190612.models.DeleteContentReviewTemplateRequest`
@@ -910,7 +910,7 @@ class MpsClient(AbstractClient):
 
 
     def DescribeContentReviewTemplates(self, request):
-        """This API is used to get the list of intelligent content recognition templates using their unique ID. The returned result includes all custom templates that meet the conditions as well as preset intelligent content recognition templates.
+        """This API is used to query content moderation templates by template ID. Both custom and preset templates that match the template IDs passed in will be returned.
 
         :param request: Request instance for DescribeContentReviewTemplates.
         :type request: :class:`tencentcloud.mps.v20190612.models.DescribeContentReviewTemplatesRequest`
@@ -1351,7 +1351,7 @@ class MpsClient(AbstractClient):
 
 
     def ExecuteFunction(self, request):
-        """This API is only used in unique custom development scenarios. Unless requested by Media Processing Service customer service, please do not call it.
+        """This API is reserved for special circumstances. Do not use it unless you are directed to use it by technical support.
 
         :param request: Request instance for ExecuteFunction.
         :type request: :class:`tencentcloud.mps.v20190612.models.ExecuteFunctionRequest`
@@ -1527,7 +1527,7 @@ class MpsClient(AbstractClient):
 
 
     def ModifyContentReviewTemplate(self, request):
-        """This API is used to modify a custom intelligent content recognition template.
+        """This API is used to modify a custom content moderation template.
 
         :param request: Request instance for ModifyContentReviewTemplate.
         :type request: :class:`tencentcloud.mps.v20190612.models.ModifyContentReviewTemplateRequest`
